# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/asset/asset_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.asset import asset_pb2 as eolymp_dot_asset_dot_asset__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n eolymp/asset/asset_service.proto\x12\x0c\x65olymp.asset\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x18\x65olymp/asset/asset.proto2\x9f\x01\n\x0c\x41ssetService\x12\x8e\x01\n\x0bUploadImage\x12\x1e.eolymp.asset.UploadImageInput\x1a\x1f.eolymp.asset.UploadImageOutput\">\x82\xe3\n\x15\x8a\xe3\n\x11\x61sset:image:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x10\"\x0e/assets/imagesB-Z+github.com/eolymp/go-sdk/eolymp/asset;assetb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.asset.asset_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/asset;asset'
  _ASSETSERVICE.methods_by_name['UploadImage']._options = None
  _ASSETSERVICE.methods_by_name['UploadImage']._serialized_options = b'\202\343\n\025\212\343\n\021asset:image:write\352\342\n\013\365\342\n\000\000\000@\370\342\nd\202\323\344\223\002\020\"\016/assets/images'
  _ASSETSERVICE._serialized_start=176
  _ASSETSERVICE._serialized_end=335
# @@protoc_insertion_point(module_scope)
