# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/taxonomy/topic_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.taxonomy import topic_pb2 as eolymp_dot_taxonomy_dot_topic__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#eolymp/taxonomy/topic_service.proto\x12\x0f\x65olymp.taxonomy\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x1b\x65olymp/taxonomy/topic.proto\x1a!eolymp/wellknown/expression.proto\"9\n\x10\x43reateTopicInput\x12%\n\x05topic\x18\x01 \x01(\x0b\x32\x16.eolymp.taxonomy.Topic\"%\n\x11\x43reateTopicOutput\x12\x10\n\x08topic_id\x18\x01 \x01(\t\"$\n\x10\x44\x65leteTopicInput\x12\x10\n\x08topic_id\x18\x01 \x01(\t\"\x13\n\x11\x44\x65leteTopicOutput\"\xba\x01\n\x10UpdateTopicInput\x12\x36\n\x05patch\x18\x01 \x03(\x0e\x32\'.eolymp.taxonomy.UpdateTopicInput.Patch\x12\x10\n\x08topic_id\x18\x02 \x01(\t\x12%\n\x05topic\x18\x03 \x01(\x0b\x32\x16.eolymp.taxonomy.Topic\"5\n\x05Patch\x12\x07\n\x03\x41LL\x10\x00\x12\x08\n\x04NAME\x10\x01\x12\x0b\n\x07SUMMARY\x10\x02\x12\x0c\n\x08KEYWORDS\x10\x03\"\x13\n\x11UpdateTopicOutput\"6\n\x12\x44\x65scribeTopicInput\x12\x10\n\x08topic_id\x18\x01 \x01(\t\x12\x0e\n\x06locale\x18\x64 \x01(\t\"<\n\x13\x44\x65scribeTopicOutput\x12%\n\x05topic\x18\x01 \x01(\x0b\x32\x16.eolymp.taxonomy.Topic\"\xf0\x01\n\x0fListTopicsInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x38\n\x07\x66ilters\x18( \x01(\x0b\x32\'.eolymp.taxonomy.ListTopicsInput.Filter\x12\x0e\n\x06locale\x18\x64 \x01(\t\x1au\n\x06\x46ilter\x12\r\n\x05query\x18\x01 \x01(\t\x12*\n\x02id\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x30\n\x04name\x18\x03 \x03(\x0b\x32\".eolymp.wellknown.ExpressionString\"H\n\x10ListTopicsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12%\n\x05items\x18\x02 \x03(\x0b\x32\x16.eolymp.taxonomy.Topic\"p\n\x13TranslateTopicInput\x12\x10\n\x08topic_id\x18\x01 \x01(\t\x12\x0e\n\x06locale\x18\x02 \x01(\t\x12\x37\n\x0btranslation\x18\x03 \x01(\x0b\x32\".eolymp.taxonomy.Topic.Translation\"\x16\n\x14TranslateTopicOutput\":\n\x16\x44\x65leteTranslationInput\x12\x10\n\x08topic_id\x18\x01 \x01(\t\x12\x0e\n\x06locale\x18\x02 \x01(\t\"\x19\n\x17\x44\x65leteTranslationOutput\"\xc3\x01\n\x15ListTranslationsInput\x12\x10\n\x08topic_id\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12>\n\x07\x66ilters\x18( \x01(\x0b\x32-.eolymp.taxonomy.ListTranslationsInput.Filter\x1a:\n\x06\x46ilter\x12\x30\n\x06locale\x18\x01 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\"Z\n\x16ListTranslationsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12\x31\n\x05items\x18\x02 \x03(\x0b\x32\".eolymp.taxonomy.Topic.Translation2\xcb\n\n\x0cTopicService\x12\x90\x01\n\x0b\x43reateTopic\x12!.eolymp.taxonomy.CreateTopicInput\x1a\".eolymp.taxonomy.CreateTopicOutput\":\x82\xe3\n\x18\x8a\xe3\n\x14taxonomy:topic:write\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\t\"\x07/topics\x12\x9b\x01\n\x0b\x44\x65leteTopic\x12!.eolymp.taxonomy.DeleteTopicInput\x1a\".eolymp.taxonomy.DeleteTopicOutput\"E\x82\xe3\n\x18\x8a\xe3\n\x14taxonomy:topic:write\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x14*\x12/topics/{topic_id}\x12\x9b\x01\n\x0bUpdateTopic\x12!.eolymp.taxonomy.UpdateTopicInput\x1a\".eolymp.taxonomy.UpdateTopicOutput\"E\x82\xe3\n\x18\x8a\xe3\n\x14taxonomy:topic:write\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x14\x1a\x12/topics/{topic_id}\x12\xa0\x01\n\rDescribeTopic\x12#.eolymp.taxonomy.DescribeTopicInput\x1a$.eolymp.taxonomy.DescribeTopicOutput\"D\x82\xe3\n\x17\x8a\xe3\n\x13taxonomy:topic:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x14\x12\x12/topics/{topic_id}\x12\x8c\x01\n\nListTopics\x12 .eolymp.taxonomy.ListTopicsInput\x1a!.eolymp.taxonomy.ListTopicsOutput\"9\x82\xe3\n\x17\x8a\xe3\n\x13taxonomy:topic:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\t\x12\x07/topics\x12\xba\x01\n\x0eTranslateTopic\x12$.eolymp.taxonomy.TranslateTopicInput\x1a%.eolymp.taxonomy.TranslateTopicOutput\"[\x82\xe3\n\x18\x8a\xe3\n\x14taxonomy:topic:write\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02*\x1a(/topics/{topic_id}/translations/{locale}\x12\xc3\x01\n\x11\x44\x65leteTranslation\x12\'.eolymp.taxonomy.DeleteTranslationInput\x1a(.eolymp.taxonomy.DeleteTranslationOutput\"[\x82\xe3\n\x18\x8a\xe3\n\x14taxonomy:topic:write\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02**(/topics/{topic_id}/translations/{locale}\x12\xb6\x01\n\x10ListTranslations\x12&.eolymp.taxonomy.ListTranslationsInput\x1a\'.eolymp.taxonomy.ListTranslationsOutput\"Q\x82\xe3\n\x17\x8a\xe3\n\x13taxonomy:topic:read\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02!*\x1f/topics/{topic_id}/translationsB3Z1github.com/eolymp/go-sdk/eolymp/taxonomy;taxonomyb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.taxonomy.topic_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z1github.com/eolymp/go-sdk/eolymp/taxonomy;taxonomy'
  _TOPICSERVICE.methods_by_name['CreateTopic']._options = None
  _TOPICSERVICE.methods_by_name['CreateTopic']._serialized_options = b'\202\343\n\030\212\343\n\024taxonomy:topic:write\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\323\344\223\002\t\"\007/topics'
  _TOPICSERVICE.methods_by_name['DeleteTopic']._options = None
  _TOPICSERVICE.methods_by_name['DeleteTopic']._serialized_options = b'\202\343\n\030\212\343\n\024taxonomy:topic:write\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\323\344\223\002\024*\022/topics/{topic_id}'
  _TOPICSERVICE.methods_by_name['UpdateTopic']._options = None
  _TOPICSERVICE.methods_by_name['UpdateTopic']._serialized_options = b'\202\343\n\030\212\343\n\024taxonomy:topic:write\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\323\344\223\002\024\032\022/topics/{topic_id}'
  _TOPICSERVICE.methods_by_name['DescribeTopic']._options = None
  _TOPICSERVICE.methods_by_name['DescribeTopic']._serialized_options = b'\202\343\n\027\212\343\n\023taxonomy:topic:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\024\022\022/topics/{topic_id}'
  _TOPICSERVICE.methods_by_name['ListTopics']._options = None
  _TOPICSERVICE.methods_by_name['ListTopics']._serialized_options = b'\202\343\n\027\212\343\n\023taxonomy:topic:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\t\022\007/topics'
  _TOPICSERVICE.methods_by_name['TranslateTopic']._options = None
  _TOPICSERVICE.methods_by_name['TranslateTopic']._serialized_options = b'\202\343\n\030\212\343\n\024taxonomy:topic:write\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\323\344\223\002*\032(/topics/{topic_id}/translations/{locale}'
  _TOPICSERVICE.methods_by_name['DeleteTranslation']._options = None
  _TOPICSERVICE.methods_by_name['DeleteTranslation']._serialized_options = b'\202\343\n\030\212\343\n\024taxonomy:topic:write\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\323\344\223\002**(/topics/{topic_id}/translations/{locale}'
  _TOPICSERVICE.methods_by_name['ListTranslations']._options = None
  _TOPICSERVICE.methods_by_name['ListTranslations']._serialized_options = b'\202\343\n\027\212\343\n\023taxonomy:topic:read\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\323\344\223\002!*\037/topics/{topic_id}/translations'
  _CREATETOPICINPUT._serialized_start=219
  _CREATETOPICINPUT._serialized_end=276
  _CREATETOPICOUTPUT._serialized_start=278
  _CREATETOPICOUTPUT._serialized_end=315
  _DELETETOPICINPUT._serialized_start=317
  _DELETETOPICINPUT._serialized_end=353
  _DELETETOPICOUTPUT._serialized_start=355
  _DELETETOPICOUTPUT._serialized_end=374
  _UPDATETOPICINPUT._serialized_start=377
  _UPDATETOPICINPUT._serialized_end=563
  _UPDATETOPICINPUT_PATCH._serialized_start=510
  _UPDATETOPICINPUT_PATCH._serialized_end=563
  _UPDATETOPICOUTPUT._serialized_start=565
  _UPDATETOPICOUTPUT._serialized_end=584
  _DESCRIBETOPICINPUT._serialized_start=586
  _DESCRIBETOPICINPUT._serialized_end=640
  _DESCRIBETOPICOUTPUT._serialized_start=642
  _DESCRIBETOPICOUTPUT._serialized_end=702
  _LISTTOPICSINPUT._serialized_start=705
  _LISTTOPICSINPUT._serialized_end=945
  _LISTTOPICSINPUT_FILTER._serialized_start=828
  _LISTTOPICSINPUT_FILTER._serialized_end=945
  _LISTTOPICSOUTPUT._serialized_start=947
  _LISTTOPICSOUTPUT._serialized_end=1019
  _TRANSLATETOPICINPUT._serialized_start=1021
  _TRANSLATETOPICINPUT._serialized_end=1133
  _TRANSLATETOPICOUTPUT._serialized_start=1135
  _TRANSLATETOPICOUTPUT._serialized_end=1157
  _DELETETRANSLATIONINPUT._serialized_start=1159
  _DELETETRANSLATIONINPUT._serialized_end=1217
  _DELETETRANSLATIONOUTPUT._serialized_start=1219
  _DELETETRANSLATIONOUTPUT._serialized_end=1244
  _LISTTRANSLATIONSINPUT._serialized_start=1247
  _LISTTRANSLATIONSINPUT._serialized_end=1442
  _LISTTRANSLATIONSINPUT_FILTER._serialized_start=1384
  _LISTTRANSLATIONSINPUT_FILTER._serialized_end=1442
  _LISTTRANSLATIONSOUTPUT._serialized_start=1444
  _LISTTRANSLATIONSOUTPUT._serialized_end=1534
  _TOPICSERVICE._serialized_start=1537
  _TOPICSERVICE._serialized_end=2892
# @@protoc_insertion_point(module_scope)
