# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/discussion/forum_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.discussion import forum_pb2 as eolymp_dot_discussion_dot_forum__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%eolymp/discussion/forum_service.proto\x12\x11\x65olymp.discussion\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x1d\x65olymp/discussion/forum.proto\x1a!eolymp/wellknown/expression.proto\"6\n\x12\x44\x65scribeForumInput\x12\x10\n\x08\x66orum_id\x18\x01 \x01(\t\x12\x0e\n\x06render\x18\x02 \x01(\x08\">\n\x13\x44\x65scribeForumOutput\x12\'\n\x05\x66orum\x18\x01 \x01(\x0b\x32\x18.eolymp.discussion.Forum\"\xf3\x01\n\x0fListForumsInput\x12\x0e\n\x06render\x18\x01 \x01(\x08\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12:\n\x07\x66ilters\x18( \x01(\x0b\x32).eolymp.discussion.ListForumsInput.Filter\x1av\n\x06\x46ilter\x12\r\n\x05query\x18\x01 \x01(\t\x12*\n\x02id\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x31\n\tparent_id\x18\x03 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\"J\n\x10ListForumsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12\'\n\x05items\x18\x02 \x03(\x0b\x32\x18.eolymp.discussion.Forum\";\n\x10\x43reateForumInput\x12\'\n\x05\x66orum\x18\x01 \x01(\x0b\x32\x18.eolymp.discussion.Forum\"%\n\x11\x43reateForumOutput\x12\x10\n\x08\x66orum_id\x18\x01 \x01(\t\"M\n\x10UpdateForumInput\x12\x10\n\x08\x66orum_id\x18\x01 \x01(\t\x12\'\n\x05\x66orum\x18\x02 \x01(\x0b\x32\x18.eolymp.discussion.Forum\"\x13\n\x11UpdateForumOutput\"$\n\x10\x44\x65leteForumInput\x12\x10\n\x08\x66orum_id\x18\x01 \x01(\t\"\x13\n\x11\x44\x65leteForumOutput2\xae\x06\n\x0c\x46orumService\x12\xa7\x01\n\rDescribeForum\x12%.eolymp.discussion.DescribeForumInput\x1a&.eolymp.discussion.DescribeForumOutput\"G\x82\xe3\n\x19\x8a\xe3\n\x15\x64iscussion:forum:read\xea\xe2\n\x0c\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\n\xf4\x03\x82\xd3\xe4\x93\x02\x14\x12\x12/forums/{forum_id}\x12\x92\x01\n\nListForums\x12\".eolymp.discussion.ListForumsInput\x1a#.eolymp.discussion.ListForumsOutput\";\x82\xe3\n\x19\x8a\xe3\n\x15\x64iscussion:forum:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\t\x12\x07/forums\x12\x96\x01\n\x0b\x43reateForum\x12#.eolymp.discussion.CreateForumInput\x1a$.eolymp.discussion.CreateForumOutput\"<\x82\xe3\n\x1a\x8a\xe3\n\x16\x64iscussion:forum:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xd3\xe4\x93\x02\t\"\x07/forums\x12\xa1\x01\n\x0bUpdateForum\x12#.eolymp.discussion.UpdateForumInput\x1a$.eolymp.discussion.UpdateForumOutput\"G\x82\xe3\n\x1a\x8a\xe3\n\x16\x64iscussion:forum:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x14\x1a\x12/forums/{forum_id}\x12\xa1\x01\n\x0b\x44\x65leteForum\x12#.eolymp.discussion.DeleteForumInput\x1a$.eolymp.discussion.DeleteForumOutput\"G\x82\xe3\n\x1a\x8a\xe3\n\x16\x64iscussion:forum:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x14*\x12/forums/{forum_id}B7Z5github.com/eolymp/go-sdk/eolymp/discussion;discussionb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.discussion.forum_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z5github.com/eolymp/go-sdk/eolymp/discussion;discussion'
  _FORUMSERVICE.methods_by_name['DescribeForum']._options = None
  _FORUMSERVICE.methods_by_name['DescribeForum']._serialized_options = b'\202\343\n\031\212\343\n\025discussion:forum:read\352\342\n\014\365\342\n\000\000\240A\370\342\n\364\003\202\323\344\223\002\024\022\022/forums/{forum_id}'
  _FORUMSERVICE.methods_by_name['ListForums']._options = None
  _FORUMSERVICE.methods_by_name['ListForums']._serialized_options = b'\202\343\n\031\212\343\n\025discussion:forum:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\t\022\007/forums'
  _FORUMSERVICE.methods_by_name['CreateForum']._options = None
  _FORUMSERVICE.methods_by_name['CreateForum']._serialized_options = b'\202\343\n\032\212\343\n\026discussion:forum:write\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\323\344\223\002\t\"\007/forums'
  _FORUMSERVICE.methods_by_name['UpdateForum']._options = None
  _FORUMSERVICE.methods_by_name['UpdateForum']._serialized_options = b'\202\343\n\032\212\343\n\026discussion:forum:write\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\323\344\223\002\024\032\022/forums/{forum_id}'
  _FORUMSERVICE.methods_by_name['DeleteForum']._options = None
  _FORUMSERVICE.methods_by_name['DeleteForum']._serialized_options = b'\202\343\n\032\212\343\n\026discussion:forum:write\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\323\344\223\002\024*\022/forums/{forum_id}'
  _DESCRIBEFORUMINPUT._serialized_start=225
  _DESCRIBEFORUMINPUT._serialized_end=279
  _DESCRIBEFORUMOUTPUT._serialized_start=281
  _DESCRIBEFORUMOUTPUT._serialized_end=343
  _LISTFORUMSINPUT._serialized_start=346
  _LISTFORUMSINPUT._serialized_end=589
  _LISTFORUMSINPUT_FILTER._serialized_start=471
  _LISTFORUMSINPUT_FILTER._serialized_end=589
  _LISTFORUMSOUTPUT._serialized_start=591
  _LISTFORUMSOUTPUT._serialized_end=665
  _CREATEFORUMINPUT._serialized_start=667
  _CREATEFORUMINPUT._serialized_end=726
  _CREATEFORUMOUTPUT._serialized_start=728
  _CREATEFORUMOUTPUT._serialized_end=765
  _UPDATEFORUMINPUT._serialized_start=767
  _UPDATEFORUMINPUT._serialized_end=844
  _UPDATEFORUMOUTPUT._serialized_start=846
  _UPDATEFORUMOUTPUT._serialized_end=865
  _DELETEFORUMINPUT._serialized_start=867
  _DELETEFORUMINPUT._serialized_end=903
  _DELETEFORUMOUTPUT._serialized_start=905
  _DELETEFORUMOUTPUT._serialized_end=924
  _FORUMSERVICE._serialized_start=927
  _FORUMSERVICE._serialized_end=1741
# @@protoc_insertion_point(module_scope)
