# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/harmony/consent.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x65olymp/harmony/consent.proto\x12\x0e\x65olymp.harmony\x1a\x1fgoogle/protobuf/timestamp.proto\"\xde\x01\n\x07\x43onsent\x12\n\n\x02id\x18\x01 \x01(\t\x12\x14\n\x0c\x61greement_id\x18\x02 \x01(\t\x12\x0f\n\x07user_id\x18\x03 \x01(\t\x12\x11\n\trevocable\x18\x04 \x01(\x08\x12.\n\x06status\x18\n \x01(\x0e\x32\x1e.eolymp.harmony.Consent.Status\x12*\n\x06set_on\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"1\n\x06Status\x12\x0b\n\x07PENDING\x10\x00\x12\x0c\n\x08\x41\x43\x43\x45PTED\x10\x01\x12\x0c\n\x08REJECTED\x10\x02\x42\x31Z/github.com/eolymp/go-sdk/eolymp/harmony;harmonyb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.harmony.consent_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z/github.com/eolymp/go-sdk/eolymp/harmony;harmony'
  _CONSENT._serialized_start=82
  _CONSENT._serialized_end=304
  _CONSENT_STATUS._serialized_start=255
  _CONSENT_STATUS._serialized_end=304
# @@protoc_insertion_point(module_scope)
